/**
 * Core component style object that contains style objects
 * for all the styles for inner elements.
 */
const coreStyles = {
    container: {
        display: 'flex',
        flexDirection: 'column',
        padding: '0 2rem 2rem 2rem',
        border: '1px solid #ccc',
        borderRadius: '0.5rem',
        boxShadow: '0.25rem 0.25rem 0.5rem 0 rgba(0, 0, 0, 0.5)',
        width: '40%',
        minWidth: '300px',
    },

    heading: {},

    label: {},

    input: {},

    toggle: {},

    button: {},

    buttonText: {},

    error: {
        marginTop: '0.25rem',
    },

    userNameContainer: {
        display: 'flex',
        flexDirection: 'column',
    },

    passwordContainer: {
        display: 'flex',
        flexDirection: 'column',
        marginTop: '1rem',
    },

    savePasswordContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        marginTop: '1rem',
    },

    showPasswordContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center',
        margin: '1rem 0',
    },
};

/**
 * Combine all styles, including context styles,
 * into a single style object for
 * @param {Object} contextStyles
 */
const getStyles = (contextStyles) => {
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },

        heading: {
            ...coreStyles.heading,
            ...contextStyles.heading,
        },

        button: {
            ...coreStyles.button,
            ...contextStyles.button,
        },

        buttonText: {
            ...coreStyles.buttonText,
            ...contextStyles.buttonText,
        },

        userNameContainer: {
            ...coreStyles.userNameContainer,
            ...contextStyles.userNameContainer,
        },

        passwordContainer: {
            ...coreStyles.passwordContainer,
            ...contextStyles.passwordContainer,
        },

        savePasswordContainer: {
            ...coreStyles.savePasswordContainer,
            ...contextStyles.savePasswordContainer,
        },

        showPasswordContainer: {
            ...coreStyles.showPasswordContainer,
            ...contextStyles.showPasswordContainer,
        },
    };
};

export default getStyles;
